@@ -19,7 +19,7 @@ You can also run this as a script with as many arguments as you
 like.  The module realizes it is a script, looks up the information
 for each MAC, and outputs it.
 
-	perl Net/Mac/Vendor.pm 00:0d:93:29:f6:c2 00:0d:93:29:f6:c5
+	perl Net/MAC/Vendor.pm 00:0d:93:29:f6:c2 00:0d:93:29:f6:c5
 
 =head1 DESCRIPTION
 
@@ -67,7 +67,7 @@ our $Cached = do {
 		{};
 		};
 
-our $VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ m/ (\d+) \. (\d+) /xg;
+our $VERSION = sprintf "%d.%02d", q$Revision: 1.16 $ =~ m/ (\d+) \. (\d+) /xg;
 
 =item run( @macs )
 
